@@ -1,4 +1,3 @@
-import inspect
 import logging
 import os
 import subprocess
@@ -6,15 +5,10 @@ import subprocess
 from netqasm.logging.glob import set_log_level
 
 
-def _has_first_argument(function, argument):
-    """Checks if a function takes a named argument as the first argument"""
-    argnames = inspect.getfullargspec(function).args
-    return argnames[0] == "no_output"
-
-
 def main():
     set_log_level(logging.WARNING)
     path_to_here = os.path.dirname(os.path.abspath(__file__))
+    errors = []
     for root, _folders, files in os.walk(path_to_here):
         for filename in files:
             if (
@@ -23,12 +17,19 @@ def main():
                 filepath = os.path.join(root, filename)
                 print(f"Running example {filepath}")
                 result = subprocess.run(
-                    ["python3", filepath], stdout=subprocess.DEVNULL, cwd=root
+                    ["python3", filepath, "--test_run"],
+                    stdout=subprocess.DEVNULL,
+                    cwd=root,
                 )
                 if result.returncode != 0:
-                    raise RuntimeError(f"Example {filepath} failed!")
+                    errors.append(f"Example {filepath} failed!")
 
-    print("All examples work!")
+    if len(errors) == 0:
+        print("All examples work!")
+    else:
+        for error in errors:
+            print(error)
+            raise RuntimeError(f"{len(errors)} examples failed!")
 
 
 if __name__ == "__main__":
