@@ -2,9 +2,8 @@ import unittest
 
 import netsquid as ns
 from netqasm.backend.messages import InitNewAppMessage, OpenEPRSocketMessage
+from netsquid_netbuilder.modules.qdevices.nv import NVQDeviceBuilder, NVQDeviceConfig
 
-from squidasm.run.stack.build import build_nv_qdevice
-from squidasm.run.stack.config import NVQDeviceConfig
 from squidasm.sim.stack.handler import Handler
 from squidasm.sim.stack.netstack import EprSocket, Netstack
 from squidasm.sim.stack.stack import NodeStack
@@ -13,7 +12,7 @@ from squidasm.sim.stack.stack import NodeStack
 class TestHandler(unittest.TestCase):
     def setUp(self) -> None:
         ns.sim_reset()
-        qdevice = build_nv_qdevice("nv_qdevice_alice", cfg=NVQDeviceConfig())
+        qdevice = NVQDeviceBuilder().build("nv_qdevice_alice", NVQDeviceConfig())
         self._node = NodeStack("alice", qdevice_type="nv", qdevice=qdevice)
 
     @property
