@@ -6,63 +6,38 @@ from netqasm.lang.instr.flavour import NVFlavour
 from netqasm.lang.parsing import parse_text_subroutine
 from netsquid.components import QuantumProcessor
 from netsquid.qubits import ketstates, qubitapi
-from netsquid_magic.link_layer import (
-    MagicLinkLayerProtocolWithSignaling,
-    SingleClickTranslationUnit,
+from netsquid_netbuilder.modules.qdevices.nv import NVQDeviceConfig
+from netsquid_netbuilder.modules.qlinks.depolarise import DepolariseQLinkConfig
+from netsquid_netbuilder.util.network_generation import (
+    create_2_node_network,
+    create_single_node_network,
 )
-from netsquid_nv.magic_distributor import NVSingleClickMagicDistributor
 
 from pydynaa import EventExpression
-from squidasm.run.stack.build import build_nv_qdevice
-from squidasm.run.stack.config import NVQDeviceConfig
+from squidasm.run.stack.run import _run, _setup_network
 from squidasm.sim.stack.common import AppMemory
 from squidasm.sim.stack.processor import NVProcessor
-from squidasm.sim.stack.qnos import Qnos
-from squidasm.sim.stack.stack import NodeStack
 
 
 class TestProcessorTwoNodes(unittest.TestCase):
     def setUp(self) -> None:
         ns.sim_reset()
-        alice_qdevice = build_nv_qdevice(
-            "nv_qdevice_alice", cfg=NVQDeviceConfig.perfect_config()
+        ns.nodes.node._node_ID_counter = -1
+        network_cfg = create_2_node_network(
+            qlink_typ="depolarise",
+            qlink_cfg=DepolariseQLinkConfig(fidelity=1, prob_success=0.5, t_cycle=10),
+            qdevice_typ="nv",
+            qdevice_cfg=NVQDeviceConfig(),
         )
-        self._alice = NodeStack(
-            "alice", qdevice_type="nv", qdevice=alice_qdevice, node_id=0
-        )
-        self._alice.qnos = Qnos(self._alice.qnos_comp)
+        self.network = _setup_network(network_cfg)
 
-        bob_qdevice = build_nv_qdevice(
-            "nv_qdevice_bob", cfg=NVQDeviceConfig.perfect_config()
-        )
-        self._bob = NodeStack("bob", qdevice_type="nv", qdevice=bob_qdevice, node_id=1)
-        self._bob.qnos = Qnos(self._bob.qnos_comp)
-
-        self._alice.connect_to(self._bob)
-
-        self._link_dist = NVSingleClickMagicDistributor(
-            nodes=[self._alice.node, self._bob.node],
-            length_A=0.001,
-            length_B=0.001,
-            full_cycle=0.001,
-            t_cycle=10,
-        )
-        self._link_prot = MagicLinkLayerProtocolWithSignaling(
-            nodes=[self._alice.node, self._bob.node],
-            magic_distributor=self._link_dist,
-            translation_unit=SingleClickTranslationUnit(),
-        )
-
-        self._alice.assign_ll_protocol(self._link_prot)
-        self._bob.assign_ll_protocol(self._link_prot)
+        self._alice = self.network.stacks["Alice"]
+        self._bob = self.network.stacks["Bob"]
 
     def tearDown(self) -> None:
-        self._link_prot.start()
-        self._alice.qnos.start()
-        self._bob.qnos.start()
-
         # ns.set_qstate_formalism(ns.QFormalism.DM)
-        ns.sim_run()
+        _run(self.network)
+
         if self._check_qmem:
             self._check_qmem(self._alice.qdevice, self._bob.qdevice)
         if self._check_cmem:
@@ -143,16 +118,13 @@ class TestProcessorSingleNode(unittest.TestCase):
         ns.sim_reset()
         config = NVQDeviceConfig.perfect_config()
         config.num_qubits = 3
-        alice_qdevice = build_nv_qdevice("nv_qdevice_alice", cfg=config)
-        self._alice = NodeStack(
-            "alice", qdevice_type="nv", qdevice=alice_qdevice, node_id=0
-        )
-        self._alice.qnos = Qnos(self._alice.qnos_comp)
+        network_cfg = create_single_node_network(qdevice_typ="nv", qdevice_cfg=config)
+        self.network = _setup_network(network_cfg)
+        self._alice = self.network.stacks["Alice"]
 
     def tearDown(self) -> None:
-        self._alice.qnos.start()
+        _run(self.network)
 
-        ns.sim_run()
         if self._check_qmem:
             self._check_qmem(self._alice.qdevice)
         if self._check_cmem:
